==> asn1tools-0.61.0.tar.gz: asn1tools-0.61.0/tests/files/extensibility_implied_pp.py <==
EXPECTED = {'ExtensibilityImplied': {'extensibility-implied': True,
                          'imports': {},
                          'object-classes': {},
                          'object-sets': {},
                          'types': {'Choice': {'members': [{'name': 'a',
                                                            'type': 'INTEGER'},
                                                           '...'],
                                               'type': 'CHOICE'},
                                    'Choice2': {'members': [{'name': 'a',
                                                             'type': 'INTEGER'},
                                                            '...'],
                                                'type': 'CHOICE'},
                                    'Enum': {'values': [('one', 1),
                                                        ('two', 2),
                                                        '...'],
                                             'type': 'ENUMERATED'},
                                    'Nested': {'members': [{'members': [{'members': [{'name': 'a',
                                                                                       'type': 'INTEGER'},
                                                                                      '...'],
                                                                          'name': 'b',
                                                                          'type': 'CHOICE'},
                                                                         '...'],
                                                             'name': 'a',
                                                             'type': 'SEQUENCE'},
                                                            '...'],
                                                'type': 'SET'},
                                    'Sequence': {'members': ['...'],
                                                 'type': 'SEQUENCE'},
                                    'Sequence2': {'members': [{'default': 0,
                                                               'name': 'a',
                                                               'type': 'INTEGER'},
                                                              '...'],
                                                  'type': 'SEQUENCE'},
                                    'Sequence3': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...'],
                                                  'type': 'SEQUENCE'},
                                    'Sequence4': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...',
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}]],
                                                  'type': 'SEQUENCE'},
                                    'Sequence5': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...',
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              '...'],
                                                  'type': 'SEQUENCE'},
                                    'Sequence6': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...',
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              '...',
                                                              {'name': 'c',
                                                               'type': 'BOOLEAN'}],
                                                  'type': 'SEQUENCE'},
                                    'Sequence7': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...',
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              [{'name': 'c',
                                                                'type': 'BOOLEAN'}],
                                                              '...',
                                                              {'name': 'd',
                                                               'type': 'BOOLEAN'}],
                                                  'type': 'SEQUENCE'},
                                    'Sequence8': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              '...',
                                                              '...'],
                                                  'type': 'SEQUENCE'},
                                    'Set': {'members': ['...'], 'type': 'SET'},
                                    'Set2': {'members': [{'default': 1,
                                                          'name': 'a',
                                                          'type': 'INTEGER'},
                                                         '...'],
                                             'type': 'SET'}},
                          'values': {}}}

==> asn1tools-0.137.4.tar.gz: asn1tools-0.137.4/tests/files/extensibility_implied_pp.py <==
EXPECTED = {'ExtensibilityImplied': {'extensibility-implied': True,
                          'imports': {},
                          'object-classes': {},
                          'object-sets': {},
                          'types': {'Choice': {'members': [{'name': 'a',
                                                            'type': 'INTEGER'},
                                                           None],
                                               'type': 'CHOICE'},
                                    'Choice2': {'members': [{'name': 'a',
                                                             'type': 'INTEGER'},
                                                            None],
                                                'type': 'CHOICE'},
                                    'Enum': {'values': [('one', 1),
                                                        ('two', 2),
                                                        None],
                                             'type': 'ENUMERATED'},
                                    'Nested': {'members': [{'members': [{'members': [{'name': 'a',
                                                                                       'type': 'INTEGER'},
                                                                                      None],
                                                                          'name': 'b',
                                                                          'type': 'CHOICE'},
                                                                         None],
                                                             'name': 'a',
                                                             'type': 'SEQUENCE'},
                                                            None],
                                                'type': 'SET'},
                                    'Sequence': {'members': [None],
                                                 'type': 'SEQUENCE'},
                                    'Sequence2': {'members': [{'default': 0,
                                                               'name': 'a',
                                                               'type': 'INTEGER'},
                                                              None],
                                                  'type': 'SEQUENCE'},
                                    'Sequence3': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None],
                                                  'type': 'SEQUENCE'},
                                    'Sequence4': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None,
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}]],
                                                  'type': 'SEQUENCE'},
                                    'Sequence5': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None,
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              None],
                                                  'type': 'SEQUENCE'},
                                    'Sequence6': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None,
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              None,
                                                              {'name': 'c',
                                                               'type': 'BOOLEAN'}],
                                                  'type': 'SEQUENCE'},
                                    'Sequence7': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None,
                                                              [{'name': 'b',
                                                                'type': 'BOOLEAN'}],
                                                              [{'name': 'c',
                                                                'type': 'BOOLEAN'}],
                                                              None,
                                                              {'name': 'd',
                                                               'type': 'BOOLEAN'}],
                                                  'type': 'SEQUENCE'},
                                    'Sequence8': {'members': [{'name': 'a',
                                                               'type': 'BOOLEAN'},
                                                              None,
                                                              None],
                                                  'type': 'SEQUENCE'},
                                    'Set': {'members': [None], 'type': 'SET'},
                                    'Set2': {'members': [{'default': 1,
                                                          'name': 'a',
                                                          'type': 'INTEGER'},
                                                         None],
                                             'type': 'SET'}},
                          'values': {}}}
